*****************************************************************************************************
* ********************   A regression discontinuity evaluation of reducing     * ******************** 
* ********************   early retirement eligibility in Poland                * ******************** 
* The data need to be acquired individually from Central Statistical Office of Poland (we are not at liberty to distiribute the data)
* The data need to be harmonized in terms of variable names (the original files distributed by CSO change variable names between waves of the survey).

* In case of any questions, please contact 
* Oliwia Komada
* okomada@grape.org.pl
*****************************************************************************************************

/* Table of contents:
Part 1   - Data preparation
Part II  - LFS data merge: ZG (hh roster) and ZD (personal file)
Part III - Generating auxiliary variables on merged data sets
    RDD: eligibility criteria
    Controls: education, Other retired in hh, Other workers in hh, Kid in hh
Part IV - Combining into panel data
Part V  - Coding variables for RDD
       Assignment variable
       Treatment: Variables responsible for notifying changes in
                  activity and retirement
       Control variables, heterogeneity of effects
Part VI  - Results
           Main, placebo, heterogeneity
*/

*********************************
*** Part 1 - Data preparation 
*********************************
cret li
cd "`c(cmd)'"

global katalog="_data"
global source_zd="$katalog\source_zd"      
global source_zg="$katalog\source_zg"      
global analysis = "$katalog\analysis"      
global results2018="$katalog\results2018"  

global zmienne "won nrm nrg rok klm ot won nrm nrg nro nrank nrpr age waga p83* p84* ps12* ps11* p50* p66* p68* education occupation SEnf SEf WE U I LMS stc mstat klm gender  mstat  mscbad tyg ur tenure_g "

cd "$analysis"

forvalues year = 2007(1)2012 {
	forvalues q = 1(1)4 {
		use "$source_zd\\`year'_`q'_analiza", clear
		capture rename stcyw stc
		capture rename rok_ur rok
		duplicates drop won nrm nrg nro nrank pl rok stc wyksz , force
		destring won, replace
		destring wyksz, replace
		capture drop _merge
		keep $zmienne
		compress
		save "$analysis\\`year'_`q'_zd", replace
	}
}

*********************************
*** Part II - Data merge ZG (household) and ZD (labor market)
*********************************
forvalues year = 2007(1)2012 {
	forvalues q = 1(1)4 {
		use "$source_zg\zga_`year'q`q'", clear
		capture drop _merge

		duplicates report woj nrm nrg  klm ot 
		rename waga waga_g
		capture gen won=woj
		destring won, replace
		capture destring nrm, replace
		capture destring nrg, replace
		capture destring nro, replace
		capture destring rok, replace
		capture destring wyksz, replace	
		capture destring klm, replace
		capture destring ot, replace
 		joinby won nrm nrg  klm ot using "$analysis\\`year'_`q'_zd", unmatched(both)
		tab _merge

		save "$analysis\\`year'_`q'_merged", replace
	}
}

*********************************
*** Part III - Generating auxiliary variables on merged data sets
*********************************
forvalues year = 2007(1)2012 {
	forvalues q = 1(1)4 {
	
	use "$analysis\\`year'_`q'_merged", clear

	capture drop house_id 
	egen house_id=group(won nrm nrg)

	*drop age
	drop if rok<1850
	drop if rok==.
	capture drop jeden house_size
	gen jeden=1
	by house_id, sort: egen house_size=sum(jeden)
	
	capture drop kid
	gen kid=0
	replace kid=1 if age<15
	capture drop smallkid6
	gen smallkid6=0
	replace smallkid6=1 if age<6
	
	capture drop house_kids house_smallkids6
	by house_id, sort: egen house_kids=sum(kid)
	by house_id, sort: egen house_smallkids6=sum(smallkid6)

	capture drop house_adult
	gen house_adult=house_size-house_kids
	
	capture drop kidage house_meankidage
	gen kidage=kid*age
	by house_id, sort: egen house_meankidage=mean(kidage)
	
	capture drop E 
	gen E=0
	replace E=1 if LMS==1 | LMS==2 | LMS==3 | LMS==6 | LMS==7
	
	capture drop house_earners
	by house_id, sort: egen house_earners=sum(E)
	drop E
	
	capture drop retire
	gen retire=0
	replace retire=1 if p84==4
	*based on an individual declaration
	
	capture drop out_of_syst
	gen out_of_syst=0
	replace out_of_syst=1 if ps12==2 | ps11==2 | p50==0111 | p50==0121 | p50==0131 | p50==0141 | p50==3451 | p50==3452 | p50==3453 | p50==3451 | p50==3451 | p50==2422
	replace out_of_syst=1 if p66==0111 | p66==0121 | p66==0131 | p66==0141 | p66==3451 | p66==3452 | p66==3453 | p66==3451 | p66==3451 | p66==2422
	* elimination of occupations that are definitely not in the system
	
	capture drop benefits
	gen benefits=0
	replace benefits=1 if p83_w1==4 | p83_w2==4 | p83_w3==4  | p83_glowne==4 | p83_w1==7 | p83_w2==7 | p83_w3==7  | p83_glowne==7 
	*based on info about individual income sources (up to three options can be declared)

	capture drop retir house_retir
	gen retir=0
	replace retir=1 if retire==1 | benefits==1
	by house_id, sort: egen house_retir=sum(retir)
	
	keep if out_of_syst==0
	
	* 2008 eligibility reform
	
	capture drop bridging
	gen bridging =0
	capture drop bridging_narr
	gen bridging_narr=0

* Coding people in pre-retirement age before and after 2008 eligibility reform
* bridging - (1 - eligible after reform - classification is little too wide) 
* bridging_narr - (1 - eligible after reform - classification is little too narrow)
* Coding of occupations was done by hand, based on the list of occupations published by [XXXXX] in 2009. 
* This list of occupations was an element of the reform, from 2009 onwards medical criteria were to decide.
* zaw = occupation (zawod in Polish is occupation in English)

	  local zaw_war2010 "8112	2146	9311	7542	3117	2114	7211	8181	3132	7112	7125	7221	8122	8121	8342	8343	9333	7124	7314	7451	8350	6223	3151	3152	8113	3153	3134	7212	7127	7214	7213	7116	7133	7535	6210	7117	7126	3437	9611	9612	8181	3132"
	  local zaw_char2010 "3153	3154	7232	3152	8311	8312	8331	8332	2111	8343	3133	3134	7542	3439	3131	8182	2144	7412	7413	2240	3256	5419	5411	6210	5311	5412	1349	2359	2635	5312	2352	5321	2289	2212	2222"
	 
	  local zaw_war2010a "8112	9311	7542	3117	7211	8181	7221	8122	8121	8342	8343	9333	7314	7451	8350	6223	3151	3152	8113	3153	6210	7117	3437	9611	9612	8181	3132"
	  local zaw_char2010a "3153	3154	7232	3152	8311	8312	8331	8343	3133	3134	7542	3131	8182	7412	7413	2240	3256	5419	5411	5412	2352	2212	2222"
	 
	 
	  local zaw_war2007 "8112	2147	9311	7112	3117	2114	7211	8131	8163	7121	7135	7221	8223	7221	8332	8333	9331	7134	7321	7216	8341	6331	3141	3142	8113	3143	3212	7212	7233	7214	7213	7124	7143	7441	6311	7125	7136	3473	9161	9161	8132	8163"
	  local zaw_char2007  "3143	3144	7232	8341	8311	8312	8322	8323	2111	8333	2231	3152	7112	3436	8151	8162	2145	7241	7244	2239	3229	5159	5151	6311	3143	5152	1229	2351	2445	5131	2341	5132	2239	2231	2241" 
	 
	  local zaw_war2007a "8112	9311	7112	3117	7211	8131	7221	8223	7221	8332	8333	9331	7321	7216	8341	6331	3141	3142	8113	3143	6311	7125	3473	9161	9161	8132	8163"
	  local zaw_char2007a "3143	3144	7232	8341	8311	8312	8322	8333	2231	3152	7112	8151	8162	7241	7244	2239	3229	5159	5151	5152	2341	2231	2241"
	 
 
 		capture drop zawod_all
		gen zawod_all=p50
	    replace zawod_all=p66 if p50==. 
		

if `year'<2011 {
		foreach num of numlist `zaw_war2007' `zaw_char2007' {
			replace bridging=1 if zawod_all==`num'
        }
		
		foreach num of numlist `zaw_war2007a' `zaw_char2007a' {
			replace bridging_narr=1 if zawod_all==`num'
        }
}


if `year'>=2011 {
		foreach num of numlist `zaw_war2010' `zaw_char2010' {
			replace bridging=1 if zawod_all==`num'
        }
		
		foreach num of numlist `zaw_war2010a' `zaw_char2010a' {
			replace bridging_narr=1 if zawod_all==`num'
        }
}

	save "$analysis\\`year'_`q'_merged", replace
	}
}




*********************************
*** Part IV - combining into panel data 
*********************************
clear
set rmsg off

cd "$analysis"

* ------------------------------------------------------------------------------
*** Rename veriables 

forvalues rok = 2007(1)2012 {
	forvalues q = 1(1)4 {
		use  "$analysis\\`rok'_`q'_merged.dta", clear

		gen year=`rok'

		drop d2w1-d31
		compress

		capture drop czas
		gen czas = "`rok'q`q'"
		capture drop quarter
		gen quarter =quarterly(czas, "yq")

		capture rename nrobs nobs
		capture rename nrprob nrpr
		capture rename nrankiety nrank
		capture rename rok_ur rok

		capture destring _all, replace
		
		save "$analysis\\`rok'_`q'_pool", replace
		}
	}	

* ------------------------------------------------------------------------------
*** Combining into pool


cd "$analysis"
capture log close
log using duplicates, text replace
forvalues rok = 2007(1)2012 {
	forvalues q = 1(1)4 {
		use `rok'_`q'_pool.dta, clear
		di "`rok' q `q'"
		duplicates report won nrm nrg nro nrank nrpr
		save, replace
	}	
}

log close


clear


forvalues rok = 2007(1)2012 {
	forvalues q = 1(1)4 {
		append using `rok'_`q'_pool.dta
		compress
	}	
}


save pool.dta, replace


cd "$analysis"
recode nrank .=0


egen id=group(won nrm nrg nro nrank nrpr gender)
drop if id==. 
duplicates report id quarter
duplicates drop id quarter, force
tsset id quarter

count if ((l.gender!=gender & l.gender!=.) | (l`3'.gender!=gender & l`3'.gender!=.))

gen jedynki=1
bysort id: egen ile=total(jedynki)
tab ile
tab ile if ((gender == 1 &  age < 61 & age >54 ) | (gender == 0  & age < 66 & age >59)) 

drop if ile==1 | ile>4

save panel.dta, replace

* ------------------------------------------------------------------------------
*** Correction - drop of observation with different dates of birth in the panel*
use panel.dta, clear
cd "$analysis"
gen check=0
by id: replace check=1 if rok!=l1.rok & l1.rok!=.
by id: replace check=1 if rok!=l3.rok & l3.rok!=.
by id: replace check=1 if rok!=l4.rok & l4.rok!=.
by id: replace check=1 if rok!=l5.rok & l5.rok!=.
count if check==1
drop if check==1
drop check

save panel.dta, clear

****************************
*** Part V coding variables for RDD
****************************
* ------------------------------------------------------------------------------
*** Assignment variable  

cd "$analysis"
use panel.dta, clear
 
* values [0,...) corresponds to people reach proper age <= 4th quarter of 2008
* values (-...,0) corresponds to people reach proper age in the 1st quarter of 2009
tsset id quarter 
gen z_q=.
gen a=.
forvalues x=0(1)5 {
	forvalues y= 0(1)3 {
	replace a= `y'/4 + tyg/52 // time in year
	
	*women
	replace z_q=2009 - rok-55 - a/2 if gender==1 & ur==1 & quarter==188+`y'+`x'*4 & l.ur!=1 
	replace z_q=2009 - rok - 55 - (a+1)/2 if gender==1 & ur==2 & quarter==188+`y' +`x'*4 
	
	*men
	replace z_q=2009 - rok-60 - a/2 if gender==0 & ur==1 & quarter==188 +`y' +`x'*4 & l.ur!=1 
	replace z_q=2009 - rok - 60 - (1+a)/2 if gender==0 & ur==2 & quarter==188 +`y' +`x'*4 
	}
}
egen z=min(z_q), by(id)  
save panel.dta, replace

* ------------------------------------------------------------------------------
*** Treatment

* Variables responsible for notifying changes in activity

cd "$analysis"
use panel.dta, clear


* activity
* flows
* flow11 - 1 flows to inactive
* flow01 - 1 flows to active
tsset id quarter
gen flow11=.
replace flow11=0 if l1.I==0 & I==0
replace flow11=1 if l1.I==0 & I==1

gen flow01=.
replace flow01=0 if l1.I==1 & I==1 
replace flow01=1 if l1.I==1 & I==0


* remaining economically active
gen remain_active=.
replace remain_active=1 if flow11==0 
replace remain_active=0 if flow11==1 

* transition to inactivity (elderly with sufficient age)
gen inactiv=.
replace inactiv=1 if (flow11==1 ) & age>45 & age<75
replace inactiv=0 if (flow11==0 ) & age>45 & age<75

* transition to inactivity (elderly with sufficient experience)
gen inactiv_eligibile=. 
replace inactiv_eligibile=1 if (flow11==1 ) & age>45 & age<75 & ((p68>=35 & gender==0) | (p68>=30 & gender==1))
replace inactiv_eligibile=0 if (flow11==0 ) & age>45 & age<75 & ((p68>=35 & gender==0) | (p68>=30 & gender==1))

* retirement
* flows
* flow21 - 1 flows to retirement
tsset id quarter

gen flow21=.
replace flow21=0 if retire==0 & l1.retire==0
replace flow21=1 if l1.retire==0 & retire==1
replace flow21=1 if l1'.benefits==0 & benefits==1


gen no_retire=.
replace no_retire=1 if flow21==0
replace no_retire=0 if flow21==1

* transition to early pension
gen retire=.
replace retire=1 if (flow21==1 ) & age>45 & age<75
replace retire=0 if (flow21==0 ) & age>45 & age<75

* ------------------------------------------------------------------------------
*** Additional variable for for robust check
gen flow_to_active=flow01
gen remain_active_max=remain_active
	replace remain_active_max=1 if z<0
gen flow_to_active_max=flow_to_active
	replace flow_to_active_max=1 if z<0
gen inactiv_max=inactiv
	replace inactiv_max=0 if z<0
gen inactiv_eligibile_max=inactiv_eligibile
	replace inactiv_eligibile_max=0 if z<0
gen retire_max=retire
	replace retire_max=0 if z<0


save panel.dta, replace

* ------------------------------------------------------------------------------
*** Fuzzy RDD 

cd "$analysis"
use panel.dta, clear
gen lost_eligibility=.
replace lost_eligibility=1 if bridging==0 & z<0 & z>=-0.25 
replace lost_eligibility=0 if bridging==1 & z>=0 
save panel.dta, replace
* ------------------------------------------------------------------------------
*** Heterogeneity of effects 
cd "$analysis"
use panel.dta, clear
*education
recode education (5=8) (4/2=11) (1=17), gen (educ_type)

*Other retired in hh
gen other_retired=house_retir>0
replace other_retired=0 if retire==1 & house_retir==1  
*Other worker in hh
gen inny_worker=house_earners>0
replace inny_worker=0 if (house_earners==1 & (LMS==1 | LMS==2 | LMS==3 | LMS==6 | LMS==7)) 

*Kid in hh
gen small_kids= house_smallkids6>0
gen kids=house_kids>0

gen Active = 1 -I


save "$analysis\panel_all.dta", replace

* ------------------------------------------------------------------------------
*** Descriptives 	
global zmienneTAB "Active retire remain_active retire inactiv inactiv_eligibile gender education  inny_worker other_retired kids "

foreach var in $zmienneTAB {
tab `var' if ((gender == 1 & rok<1954 & age < 61 & age >54 & (p68>29)) | (gender == 0 & rok<1949 & age < 66 & age >59 & (p68>34 ))) 
tab `var' if ((gender == 1 & rok<1954 & age < 61 & age >54 & (p68<30 )) | (gender == 0 & rok<1949 & age < 66 & age >59 & (p68<35 ))) 


tab `var' if ((gender == 1 & rok>1953 & age < 61 & age >54) | (gender == 0 & rok>1948 & age < 66 & age >59)) & bridging == 1
tab `var' if ((gender == 1 & rok>1953 & age < 61 & age >54) | (gender == 0 & rok>1948 & age < 66 & age >59)) & bridging == 0
}

*********************************
*** Part VI - Results
*********************************

use "$analysis\panel_all.dta", replace
cd "$results2018"

global dim "educ_type other_retired inny_worker kids gender"
global lhs "remain_active retire inactiv inactiv_eligibile"
set scheme s1mono


* ------------------------------------------------------------------------------
* Main results + Placebo test 

foreach lhs in $lhs {
		capture drop lost_eligibility_full
		gen lost_eligibility_full=0
		replace lost_eligibility_full=1 if bridging==0 & z<0 // moj zawod traci uprawnienia a ja odpowiedni wiek uzyskalabym po reformie
        
		* RDD sharp 
		rd `lhs' z if z>-5 & z<5, mbw(100) graph noscatter
		graph save "$results2018/_wykresy/rd_`lhs'_z0", replace
		graph export "$results2018/_wykresy/rd_`lhs'_z0_t.png", replace
		
		* RDD fuzzy
		rd `lhs' lost_eligibility_full z if z>-5 & z<5, mbw(100) graph noscatter
		graph save "$results2018/_wykresy/rd_`lhs'_z0_t", replace
		graph export "$results2018/_wykresy/rd_`lhs'_z0_t.png", replace
		
        * RDD max - theoretical maximum
		rd `lhs'_max z if z>-5 & z<5, mbw(100) graph noscatter
		graph save "$results2018/_wykresy/rd_`lhs'_z0_t", replace
		graph export "$results2018/_wykresy/rd_`lhs'_z0_t.png", replace
		
		}
		parmby " rd `lhs' z, mbw(100)", by() saving(`lhs' , replace)
		parmby " rd `lhs' lost_eligibility_full z, mbw(100)", by() saving(t_`lhs' , replace)
		parmby " rd `lhs'_max z, mbw(100)", by() saving(`lhs'_max , replace)			

		
		capture drop z_temp
		capture gen z_temp=.
		
			forvalues i=1(1)23 {  
				replace z_temp=z-2+`i'/4  
				
					capture drop lost_eligibility_full
					gen lost_eligibility_full=0
					replace lost_eligibility_full=1 if bridging==0 & z_temp<0 

					parmby " rd `lhs'     z_temp, mbw(100)", by() saving(q`i'_`lhs'_none , replace)
					parmby " rd `lhs'     lost_eligibility_full z_temp, mbw(100)", by() saving(qt`i'_`lhs'_none , replace)	
					
					foreach dim in $dim {
						parmby " rd `lhs' z_temp, mbw(100)", by(`dim') saving(q`i'_`lhs'_`dim' , replace)
						parmby " rd `lhs' lost_eligibility_full z_temp, mbw(100)", by(`dim') saving(qt`i'_`lhs'_`dim' , replace)
					}
			}
	    
}

* ------------------------------------------------------------------------------
* Check 1: discontinous
rd flow_to_active z, mbw(100) graph
	graph save rd_`lhs'_z0, replace
rd flow_to_active lost_eligibility_full z, mbw(100) graph
	graph save rd_`lhs'_z0_t, replace
rd flow_to_active_max z, mbw(100) graph
	graph save rd_`lhs'_z0_t, replace
	
* Check 2: Results for higher attrition:
foreach lhs in $lhs {
	forvalues 2(1)4{
		* RDD sharp 
		rd `lhs' z, mbw(100) graph
		* RDD fuzzy
		rd `lhs' lost_eligibility_full z, mbw(100) graph
	}
}

* ------------------------------------------------------------------------------	
* heterogeneity
	
clear

global dim "gender educ_type other_retired inny_worker kids"

cd "$results2018max"

foreach lhs in $lhs {
	forvalues i=1(1)23 {  
		foreach version in q qt {
		foreach dim in $dim none {
			use `version'`i'_`lhs'_`dim', clear
			capture drop lhs
			gen lhs="`lhs'"
			capture drop period
			gen period=`i'
			capture drop vars
			gen vars="`dim'" 
			capture drop treat
			gen treat="`version'"
			save, replace
			}
		}
		}
	}
			
clear

gen asia=1			

foreach lhs in $lhs {
	forvalues i=1(1)23 {  
		foreach version in q qt {
		foreach dim in $dim none {
		append using `version'`i'_`lhs'_`dim'
			}
		}
		}
	}

drop asia

foreach var in $dim {
	replace `var'=0 if `var'==.
	}
	
capture drop significant
gen significant=p<0.15
tab significant
tab significant if parm=="lwald"


capture drop estimate_sig
gen estimate_sig=estimate*significant

save _final_results_clean, replace


global dim "educ_type other_retired inny_worker kids gender"
global lhs "remain_active retire inactiv inactiv_eligibile"



use "_final_results_clean.dta", clear
keep if parm=="lwald"

ttest estimate=0 if treat=="qt" & parm=="lwald"
ttest estimate=0 if treat=="qt" & parm=="lwald" & period<10

capture drop id
tab parm
tab vars
tab lhs
tab treat
tab parmseq
tab educ_type

egen id=group(parm vars lhs treat parmseq educ_type)

foreach dim in $dim {
	count if `dim'==.
	}
	
duplicates report id period
duplicates drop id period, force

tsset id period
replace period = period + 188
format period %tq

tab period, g(time)

outsheet lhs estimate stderr z p treat if vars=="none" & parm=="lwald" & time8==1 using table_gen, replace

encode lhs, g(lewa)
lab def lhs_pl 1 "remained active" 2 "left to retirement" 3 "left" 4 "left was eligible"
lab values lewa lhs_pl

set scheme s1mono

foreach lhs in $lhs {
	twoway (tsline estimate, lcolor(blue) lwidth(thick)) (tsline min95, lpattern(dash) lcolor(blue)) (tsline max95, lpattern(dash) lcolor(blue)) if parm=="lwald" & treat=="q" &  vars=="none" & lhs=="`lhs'",  title("") xline(196) yline(0) legend(off) 
	graph save quarterly_`lhs', replace
	graph export quarterly_`lhs'.png, replace
}

encode parm, g(equation)

gen dummy=estimate_sig!=0
tab lewa, g(lefths)
tab educ_type, g(yofedu)
gen treatment=treat=="qt"

global keep "time8 gender yofedu* lefths* other_retired inny_worker kids treatment"

dprobit dummy $keep time8 if parm=="lwald"
outreg2 using table, bdec(4) bfmt(f) sdec(4) excel replace keep($keep)
reg estimate_sig $keep time8 if parm=="lwald" & estimate_sig!=0
outreg2 using table, bdec(4) bfmt(f) sdec(4) excel append keep($keep)

forvalues lewa=1(1)4 {
	dprobit dummy time8 treatment if parm=="lwald" & lewa==`lewa'
	outreg2 using table, bdec(4) bfmt(f)  excel  append keep($keep) 
	reg estimate_sig time8 treatment if parm=="lwald" & lewa==`lewa' & estimate_sig!=0
	outreg2 using table, bdec(4) bfmt(f)  excel  append keep($keep) 
}

foreach rhs in other_retired inny_worker gender kids  {
	xi: dprobit dummy time8 treatment `rhs' i.lhs i.educ_type if parm=="lwald" 
	outreg2 using tablerhs, bdec(4) bfmt(f)  excel  append 
	xi: reg estimate_sig time8 treatment `rhs' i.lhs i.educ_type if parm=="lwald" & estimate_sig!=0
	outreg2 using tablerhs, bdec(4) bfmt(f)  excel  append 
} 



ttest estimate=0 if treat=="q" & parm=="lwald"
ttest estimate=0 if treat=="qt" & parm=="lwald"
graph box estimate if treat=="q" & parm=="lwald", by(period)

forvalues lewa = 1(1)4 {
	graph box estimate if treat=="q" & parm=="lwald" & lewa==`lewa', over(period)
	graph save box_`lewa', replace
	graph export "$results2018/box_`lewa'.png", replace
	}

	
graph use box_1 
graph use box_2 
graph use box_3 
graph use box_4 

graph combine box_1 box_2 box_3 Graph


graph box estimate if treat=="qt" & parm=="lwald", over(period)
graph box estimate if treat=="qt" & parm=="numer", over(period)
graph box estimate if treat=="qt" & parm=="denom", over(period)














